
<div align="center">
  <img src="https://upload.wikimedia.org/wikipedia/commons/6/6f/Spain_flag_300.png" alt="Spanish Flag" width="200" margin='auto'>
  <h1>Aprendo</h1>
</div>

![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)



[![Connect on LinkedIn](https://img.shields.io/badge/Connect%20on-LinkedIn-blue.svg)](https://www.linkedin.com/in/lucien-holliday/)
[![GitHub issues](https://img.shields.io/github/issues/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/issues)
[![GitHub forks](https://img.shields.io/github/forks/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/network/members)
[![GitHub contributors](https://img.shields.io/github/contributors/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/graphs/contributors)
[![PyPI version](https://badge.fury.io/py/aprendo.svg)](https://badge.fury.io/py/aprendo)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation](https://img.shields.io/badge/Documentation-Wiki-brightgreen)](https://github.com/luiHoll97/aprendo/wiki)

<div align="center">
  <strong> 🐛 Currently in development. Expect bugs 🐛</strong>
</div>

## Introduction

Small passion project to test my Spanish vocab as I continue to learn the language.

Aprendo is an intuitive and user-friendly application designed to help you learn and practice Spanish. With Aprendo, you can store Spanish verbs and nouns in a local database and quiz yourself on verb conjugations to reinforce your learning.

## Features
- Local Database: Easily store and manage Spanish verbs and nouns. Your data is stored locally on your device for quick access and offline use.
- Quiz Conjugations: Test your knowledge by quizzing yourself on verb conjugations on the command line (or implement into a frontend project)
- User-Friendly Interface: Simple and clean design to help you focus on learning without distractions.

## Getting Started

### Prerequisites

Before you begin, ensure you have met the following requirements:

- You have installed the latest version of Python.
- It'd be helpful to have a basic understanding of Spanish verbs and nouns.

## Installation
To install Aprendo, follow these steps:

### Install via PYPI

`pip install aprendo`

### Clone Repository

`git@github.com:luiHoll97/aprendo.git`

- Naviagte to root of project and run:

`pip install -e .`

## Further Reading

For quickstart tutorials, head to the [wiki](https://github.com/luiHoll97/aprendo/wiki)


